import 'dart:async';

import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class FcCell extends StatefulWidget {
  const FcCell({Key? key, 
    this.onPressed,
    required this.label,
    this.crossAxisAlignment = CrossAxisAlignment.center,
    this.content,
    this.contentAlignment = Alignment.centerRight,
    this.arrow = true,
    this.border = true
  }) : super(key: key);

  final VoidCallback? onPressed; // 点击事件
  final Widget label; // 标题 Widget
  final CrossAxisAlignment crossAxisAlignment;
  final Widget? content; // 中间的 Widget
  final Alignment contentAlignment;
  final bool arrow; // 是否显示右侧箭头
  final bool border; // 是否显示边框

  @override
  _FcCellState createState() => _FcCellState();
}

class _FcCellState extends State<FcCell> {

  bool onPress = false;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: widget.onPressed,
      onHighlightChanged: (bool value) {
        if (onPress != value) {
          if (value) {
            setState(() {
              onPress = value;
            });
          } else {
            Timer(const Duration(milliseconds: 100), () {
              setState(() {
                onPress = value;
              });
            });
          }
        }
      },
      child: Stack(
        children: [
          Container(
            padding: EdgeInsets.only(left: Adapt.px(33)),
            decoration: const BoxDecoration(
              color: Colors.white
            ),
            constraints: BoxConstraints(
              minWidth: Adapt.screenW(),
              minHeight: Adapt.px(100)
            ),
            child: Container(
              padding: EdgeInsets.only(right: Adapt.px(10), top: Adapt.px(28), bottom: Adapt.px(28)),
              decoration: BoxDecoration(
                border: widget.border ? Border(
                  bottom: BorderSide(color: Colors.black.withOpacity(0.1))
                ) : null
              ),
              child: Row(
                crossAxisAlignment: widget.crossAxisAlignment,
                children: [
                  DefaultTextStyle(
                    style: TextStyle(color: const Color(0xFF323233), fontSize: Adapt.px(31), fontWeight: FontWeight.w500, height: 1.4),
                    child: widget.label
                  ),
                  Expanded(
                    child: widget.content != null ? Container(
                      alignment: widget.contentAlignment,
                      child: DefaultTextStyle(
                        style: TextStyle(color: const Color(0xFFAFAFB3), fontSize: Adapt.px(31), fontWeight: FontWeight.w500, height: 1.4),
                        child: widget.content!
                      )
                    ) : Container()
                  ),
                  widget.arrow ? Icon(Icons.keyboard_arrow_right_rounded, color: Colors.black.withOpacity(0.3), size: Adapt.px(50)) : Container()
                ]
              )
            )
          ),
          Positioned(
            top: 0,
            bottom: 0,
            left: 0,
            width: onPress ? Adapt.screenW() : 0,
            child: Container(
              width: Adapt.screenW(),
              height: Adapt.px(100),
              decoration: BoxDecoration(
                color: Colors.black.withOpacity(0.1)
              )
            )
          )
        ]
      )
    );
  }
}
